@@ -3,16 +3,19 @@ from .config import read as read_config
 from .datetime import parse_datetime, utc_now
 from .resource import read_resource
 from .service_name import SERVICE_NAME
-from .uuid import parse_uuid
+from .typing import dynamic_cast
+from .uuid import blake2b_digest_uuid, parse_uuid
 from .xdg import user_cache_dir, user_config_dir
 
 __all__ = [
     "ArgumentParser",
+    "SERVICE_NAME",
+    "blake2b_digest_uuid",
+    "dynamic_cast",
     "parse_datetime",
     "parse_uuid",
     "read_config",
     "read_resource",
-    "SERVICE_NAME",
     "user_cache_dir",
     "user_config_dir",
     "utc_now",
